@@ -743,6 +743,9 @@ const completion: Fig.Spec = {
     {
       name: "extdedup",
       options: [
+        {
+          name: "--select",
+        },
         {
           name: "--no-output",
         },
@@ -755,6 +758,12 @@ const completion: Fig.Spec = {
         {
           name: "--memory-limit",
         },
+        {
+          name: "--no-headers",
+        },
+        {
+          name: "--delimiter",
+        },
         {
           name: "--quiet",
         },
@@ -767,6 +776,12 @@ const completion: Fig.Spec = {
     {
       name: "extsort",
       options: [
+        {
+          name: "--select",
+        },
+        {
+          name: "--reverse",
+        },
         {
           name: "--memory-limit",
         },
@@ -776,6 +791,9 @@ const completion: Fig.Spec = {
         {
           name: "--jobs",
         },
+        {
+          name: "--delimiter",
+        },
         {
           name: "--no-headers",
         },
@@ -816,10 +834,10 @@ const completion: Fig.Spec = {
           name: "--new-column",
         },
         {
-          name: "--jql",
+          name: "--jaq",
         },
         {
-          name: "--jqlfile",
+          name: "--jaqfile",
         },
         {
           name: "--pretty",
@@ -897,10 +915,10 @@ const completion: Fig.Spec = {
           name: "--new-column",
         },
         {
-          name: "--jql",
+          name: "--jaq",
         },
         {
-          name: "--jqlfile",
+          name: "--jaqfile",
         },
         {
           name: "--pretty",
@@ -3386,6 +3404,9 @@ const completion: Fig.Spec = {
         {
           name: "--infer-len",
         },
+        {
+          name: "--cache-schema",
+        },
         {
           name: "--streaming",
         },
