@@ -193,6 +193,7 @@ use rayon::{
 };
 use regex::Regex;
 use serde::Deserialize;
+use smallvec::SmallVec;
 use strum_macros::EnumString;
 
 use crate::{
@@ -331,7 +332,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         EmptyReplace,
     }
 
-    let mut ops_vec: Vec<Operations> = Vec::new();
+    let mut ops_vec = SmallVec::<[Operations; 4]>::new();
 
     let applydp_cmd = if args.cmd_operations {
         match validate_operations(
@@ -417,6 +418,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         // do actual applydp command via Rayon parallel iterator
         batch
             .par_iter()
+            .with_min_len(1024)
             .map(|record_item| {
                 let mut record = record_item.clone();
                 match applydp_cmd {
@@ -495,13 +497,13 @@ fn validate_operations(
     flag_replacement: &str,
     flag_new_column: &Option<String>,
     flag_formatstr: &str,
-) -> Result<Vec<Operations>, CliError> {
+) -> Result<SmallVec<[Operations; 4]>, CliError> {
     let mut copy_invokes = 0_u8;
     let mut regex_replace_invokes = 0_u8;
     let mut replace_invokes = 0_u8;
     let mut strip_invokes = 0_u8;
 
-    let mut ops_vec: Vec<Operations> = Vec::with_capacity(operations.len());
+    let mut ops_vec = SmallVec::with_capacity(operations.len());
 
     for op in operations {
         let Ok(operation) = Operations::from_str(op) else {
@@ -586,7 +588,7 @@ fn validate_operations(
 
 #[inline]
 fn applydp_operations(
-    ops_vec: &Vec<Operations>,
+    ops_vec: &SmallVec<[Operations; 4]>,
     cell: &mut String,
     comparand: &str,
     replacement: &str,
@@ -594,7 +596,7 @@ fn applydp_operations(
     for op in ops_vec {
         match op {
             Operations::Len => {
-                *cell = cell.len().to_string();
+                *cell = itoa::Buffer::new().format(cell.len()).to_owned();
             },
             Operations::Lower => {
                 *cell = cell.to_lowercase();
@@ -604,11 +606,11 @@ fn applydp_operations(
             },
             Operations::Squeeze => {
                 let squeezer: &'static Regex = regex_oncelock!(r"\s+");
-                *cell = squeezer.replace_all(cell, " ").to_string();
+                *cell = squeezer.replace_all(cell, " ").into_owned();
             },
             Operations::Squeeze0 => {
                 let squeezer: &'static Regex = regex_oncelock!(r"\s+");
-                *cell = squeezer.replace_all(cell, "").to_string();
+                *cell = squeezer.replace_all(cell, "").into_owned();
             },
             Operations::Trim => {
                 *cell = String::from(cell.trim());
@@ -648,7 +650,7 @@ fn applydp_operations(
             Operations::Regex_Replace => {
                 // safety: we set REGEX_REPLACE in validate_operations()
                 let regexreplace = REGEX_REPLACE.get().unwrap();
-                *cell = regexreplace.replace_all(cell, replacement).to_string();
+                *cell = regexreplace.replace_all(cell, replacement).into_owned();
             },
             Operations::Round => {
                 if let Ok(num) = cell.parse::<f64>() {
