@@ -4,7 +4,12 @@ Infers extended metadata about a CSV using a large language model.
 Note that this command uses LLMs for inferencing and is therefore prone to
 inaccurate information being produced. Verify output results before using them.
 
-For examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_describegpt.rs.
+Let's say you have Ollama installed (must be v0.2.0 or above) to use LLMs locally with qsv describegpt.
+To attempt generating a data dictionary of a spreadsheet file you may run (replace <> values):
+
+qsv describegpt <filepath> --base-url http://localhost:11434/v1 --api-key ollama --model <model> --max-tokens <number> --dictionary
+
+For more examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_describegpt.rs.
 
 For more detailed info on how describegpt works and how to prepare a prompt file, 
 see https://github.com/jqnatividad/qsv/blob/master/docs/Describegpt.md
@@ -20,18 +25,20 @@ describegpt options:
                            human-readable label, a description, and stats.
     --tags                 Prints tags that categorize the dataset. Useful
                            for grouping datasets and filtering.
-    --api-key <key>        The API key to use. If using Ollama, set the key to ollama.
+    --api-key <key>        The API key to use. The default API key for Ollama is ollama.
                            If the QSV_LLM_APIKEY envvar is set, it will be used instead.                           
     --max-tokens <value>   Limits the number of generated tokens in the output.
                            [default: 50]
     --json                 Return results in JSON format.
     --jsonl                Return results in JSON Lines format.
+    --prompt <prompt>      Custom prompt passed as text (alternative to --description, etc.).
+                           Replaces {stats}, {frequency}, & {headers} in prompt with qsv command outputs.
     --prompt-file <file>   The JSON file containing the prompts to use for inferencing.
                            If not specified, default prompts will be used.
     --base-url <url>       The URL of the API for interacting with LLMs. Supports APIs
                            compatible with the OpenAI API specification (Ollama, Jan, etc.).
+                           The default base URL for Ollama is http://localhost:11434/v1.
                            [default: https://api.openai.com/v1]
-    --ollama               Required flag when using Ollama.
     --model <model>        The model to use for inferencing.
                            [default: gpt-3.5-turbo-16k]
     --timeout <secs>       Timeout for completions in seconds.
@@ -65,11 +72,11 @@ struct Args {
     flag_tags:        bool,
     flag_api_key:     Option<String>,
     flag_max_tokens:  u32,
-    flag_base_url:    String,
-    flag_ollama:      bool,
+    flag_base_url:    Option<String>,
     flag_model:       Option<String>,
     flag_json:        bool,
     flag_jsonl:       bool,
+    flag_prompt:      Option<String>,
     flag_prompt_file: Option<String>,
     flag_user_agent:  Option<String>,
     flag_timeout:     u16,
@@ -88,8 +95,12 @@ struct PromptFile {
     dictionary_prompt:  String,
     description_prompt: String,
     tags_prompt:        String,
+    prompt:             String,
     json:               bool,
     jsonl:              bool,
+    base_url:           String,
+    model:              String,
+    timeout:            u32,
 }
 
 const LLM_APIKEY_ERROR: &str = "Error: QSV_LLM_APIKEY environment variable not found.\nNote that \
@@ -132,6 +143,7 @@ fn create_client(args: &Args) -> CliResult<Client> {
         .brotli(true)
         .gzip(true)
         .deflate(true)
+        .zstd(true)
         .use_rustls_tls()
         .http2_adaptive_window(true)
         .connection_verbose(log_enabled!(log::Level::Debug) || log_enabled!(log::Level::Trace))
@@ -183,18 +195,30 @@ fn send_request(
 }
 
 // Check if model is valid, including the default model
-fn is_valid_model(client: &Client, api_key: Option<&str>, args: &Args) -> CliResult<bool> {
-    let models_endpoint = if args.flag_ollama {
-        "/api/tags"
-    } else {
-        "/models"
-    };
+fn is_valid_model(
+    client: &Client,
+    arg_is_some: impl Fn(&str) -> bool,
+    api_key: Option<&str>,
+    args: &Args,
+) -> CliResult<bool> {
+    // Get prompt file if --prompt-file is used, otherwise get default prompt file
+    let prompt_file = get_prompt_file(args)?;
+    let models_endpoint = "/models";
     let response = send_request(
         client,
         api_key,
         None,
         "GET",
-        format!("{0}{1}", args.flag_base_url, models_endpoint).as_str(),
+        format!(
+            "{0}{1}",
+            if arg_is_some("--prompt-file") {
+                prompt_file.base_url
+            } else {
+                args.flag_base_url.clone().unwrap()
+            },
+            models_endpoint
+        )
+        .as_str(),
     );
 
     // If response is an error, return the error with fail!
@@ -204,19 +228,17 @@ fn is_valid_model(client: &Client, api_key: Option<&str>, args: &Args) -> CliRes
 
     // Verify model is valid from response {"data": [{"id": "model-id", ...}, ...]
     let response_json: serde_json::Value = response.unwrap().json().unwrap();
-    if args.flag_ollama {
-        let models = response_json["models"].as_array().unwrap();
-        for model in models {
-            if model["name"].as_str().unwrap() == args.flag_model.clone().unwrap() {
-                return Ok(true);
-            }
-        }
+    let given_model = if arg_is_some("--model") {
+        args.flag_model.clone().unwrap()
+    } else if args.flag_prompt_file.is_some() {
+        prompt_file.model
     } else {
-        let models = response_json["data"].as_array().unwrap();
-        for model in models {
-            if model["id"].as_str().unwrap() == args.flag_model.clone().unwrap() {
-                return Ok(true);
-            }
+        args.flag_model.clone().unwrap()
+    };
+    let models = response_json["data"].as_array().unwrap();
+    for model in models {
+        if model["id"].as_str().unwrap() == given_model {
+            return Ok(true);
         }
     }
 
@@ -251,8 +273,14 @@ fn get_prompt_file(args: &Args) -> CliResult<PromptFile> {
             dictionary_prompt:  DEFAULT_DICTIONARY_PROMPT.to_owned(),
             description_prompt: DEFAULT_DESCRIPTION_PROMPT.to_owned(),
             tags_prompt:        DEFAULT_TAGS_PROMPT.to_owned(),
+            prompt:             "Summary statistics: {stats}\n\nFrequency: {frequency}\n\nWhat is \
+                                 this dataset about?"
+                .to_owned(),
             json:               true,
             jsonl:              false,
+            base_url:           "https://api.openai.com/v1".to_owned(),
+            model:              "gpt-3.5-turbo-16k".to_owned(),
+            timeout:            60,
         };
         default_prompt_file
     };
@@ -264,6 +292,7 @@ fn get_prompt(
     prompt_type: &str,
     stats: Option<&str>,
     frequency: Option<&str>,
+    headers: Option<&str>,
     args: &Args,
 ) -> CliResult<String> {
     // Get prompt file if --prompt-file is used, otherwise get default prompt file
@@ -274,6 +303,13 @@ fn get_prompt(
         "dictionary_prompt" => prompt_file.dictionary_prompt,
         "description_prompt" => prompt_file.description_prompt,
         "tags_prompt" => prompt_file.tags_prompt,
+        "custom" => {
+            if args.flag_prompt.is_some() {
+                args.flag_prompt.clone().unwrap()
+            } else {
+                prompt_file.prompt
+            }
+        },
         _ => {
             return fail_incorrectusage_clierror!("Error: Invalid prompt type: {prompt_type}");
         },
@@ -282,6 +318,7 @@ fn get_prompt(
     let prompt = prompt
         .replace("{stats}", stats.unwrap_or(""))
         .replace("{frequency}", frequency.unwrap_or(""))
+        .replace("{headers}", headers.unwrap_or(""))
         .replace(
             "{json_add}",
             if prompt_file.json
@@ -306,9 +343,10 @@ fn get_completion(
 ) -> CliResult<String> {
     // Create client with timeout
     let client = create_client(args)?;
+    let prompt_file = get_prompt_file(args)?;
 
     // Verify model is valid
-    if !is_valid_model(&client, Some(api_key), args)? {
+    if !is_valid_model(&client, &arg_is_some, Some(api_key), args)? {
         return fail!("Error: Invalid model.");
     }
 
@@ -326,26 +364,39 @@ fn get_completion(
         args.flag_max_tokens
     };
 
+    let model = if arg_is_some("--model") {
+        args.flag_model.clone().unwrap()
+    } else if args.flag_prompt_file.is_some() {
+        let prompt_file = get_prompt_file(args)?;
+        prompt_file.model
+    } else {
+        args.flag_model.clone().unwrap()
+    };
+
+    let base_url = if arg_is_some("--base-url") {
+        args.flag_base_url.clone().unwrap()
+    } else if args.flag_prompt_file.is_some() {
+        prompt_file.base_url
+    } else {
+        args.flag_base_url.clone().unwrap()
+    };
+
     // Create request data
     let request_data = json!({
-        "model": args.flag_model,
+        "model": model,
         "max_tokens": max_tokens,
         "messages": messages,
         "stream": false
     });
 
     // Get response from POST request to chat completions endpoint
-    let completions_endpoint = if args.flag_ollama {
-        "/api/chat"
-    } else {
-        "/chat/completions"
-    };
+    let completions_endpoint = "/chat/completions";
     let response = send_request(
         &client,
         Some(api_key),
         Some(&request_data),
         "POST",
-        format!("{0}{1}", args.flag_base_url, completions_endpoint).as_str(),
+        format!("{base_url}{completions_endpoint}").as_str(),
     )?;
 
     // Parse response as JSON
@@ -358,15 +409,10 @@ fn get_completion(
     }
 
     // Get completion from response
-    if args.flag_ollama {
-        let completion = response_json["message"]["content"].as_str().unwrap();
-        Ok(completion.to_string())
-    } else {
-        let completion = response_json["choices"][0]["message"]["content"]
-            .as_str()
-            .unwrap();
-        Ok(completion.to_string())
-    }
+    let completion = response_json["choices"][0]["message"]["content"]
+        .as_str()
+        .unwrap();
+    Ok(completion.to_string())
 }
 
 // Check if JSON output is expected
@@ -411,6 +457,7 @@ fn run_inference_options(
     api_key: &str,
     stats_str: Option<&str>,
     frequency_str: Option<&str>,
+    headers_str: Option<&str>,
 ) -> CliResult<()> {
     // Add --dictionary output as context if it is not empty
     fn get_messages(prompt: &str, dictionary_completion: &str) -> serde_json::Value {
@@ -478,9 +525,30 @@ fn run_inference_options(
     let mut completion: String;
     let mut dictionary_completion = String::new();
 
+    // Generate custom prompt output
+    if args.flag_prompt.is_some() {
+        prompt = get_prompt("custom", stats_str, frequency_str, headers_str, args)?;
+        print_status(args, "Generating custom prompt output from API...");
+        messages = get_messages(&prompt, &dictionary_completion);
+        dictionary_completion = get_completion(args, &arg_is_some, api_key, &messages)?;
+        print_status(args, "Received custom prompt completion.");
+        process_output(
+            "prompt",
+            &dictionary_completion,
+            &mut total_json_output,
+            args,
+        )?;
+    }
+
     // Generate dictionary output
     if args.flag_dictionary || args.flag_all {
-        prompt = get_prompt("dictionary_prompt", stats_str, frequency_str, args)?;
+        prompt = get_prompt(
+            "dictionary_prompt",
+            stats_str,
+            frequency_str,
+            headers_str,
+            args,
+        )?;
         print_status(args, "Generating data dictionary from API...");
         messages = get_messages(&prompt, &dictionary_completion);
         dictionary_completion = get_completion(args, &arg_is_some, api_key, &messages)?;
@@ -496,9 +564,15 @@ fn run_inference_options(
     // Generate description output
     if args.flag_description || args.flag_all {
         prompt = if args.flag_dictionary {
-            get_prompt("description_prompt", None, None, args)?
+            get_prompt("description_prompt", None, None, None, args)?
         } else {
-            get_prompt("description_prompt", stats_str, frequency_str, args)?
+            get_prompt(
+                "description_prompt",
+                stats_str,
+                frequency_str,
+                headers_str,
+                args,
+            )?
         };
         messages = get_messages(&prompt, &dictionary_completion);
         print_status(args, "Generating description from API...");
@@ -510,9 +584,9 @@ fn run_inference_options(
     // Generate tags output
     if args.flag_tags || args.flag_all {
         prompt = if args.flag_dictionary {
-            get_prompt("tags_prompt", None, None, args)?
+            get_prompt("tags_prompt", None, None, None, args)?
         } else {
-            get_prompt("tags_prompt", stats_str, frequency_str, args)?
+            get_prompt("tags_prompt", stats_str, frequency_str, headers_str, args)?
         };
         messages = get_messages(&prompt, &dictionary_completion);
         print_status(args, "Generating tags from API...");
@@ -608,10 +682,20 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .unwrap();
 
     // If no inference flags specified, print error message.
-    if !args.flag_all && !args.flag_dictionary && !args.flag_description && !args.flag_tags {
+    if !args.flag_all
+        && !args.flag_dictionary
+        && !args.flag_description
+        && !args.flag_tags
+        && args.flag_prompt.is_none()
+    {
         return fail_incorrectusage_clierror!("Error: No inference options specified.");
     // If --all flag is specified, but other inference flags are also set, print error message.
-    } else if args.flag_all && (args.flag_dictionary || args.flag_description || args.flag_tags) {
+    } else if args.flag_all
+        && (args.flag_dictionary
+            || args.flag_description
+            || args.flag_tags
+            || args.flag_prompt.is_some())
+    {
         return fail_incorrectusage_clierror!(
             "Error: --all option cannot be specified with other inference flags."
         );
@@ -660,11 +744,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         &args,
         format!("Generating frequency from {input_filename} using qsv frequency...").as_str(),
     );
-    let Ok(frequency) = Command::new(qsv_path)
+    let Ok(frequency) = Command::new(qsv_path.clone())
         .arg("frequency")
         .args(["--limit", "50"])
         .args(["--lmt-threshold", "10"])
-        .arg(input_path)
+        .arg(input_path.clone())
         .output()
     else {
         return fail!("Error: Error while generating frequency.");
@@ -675,6 +759,26 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         return fail!("Error: Unable to parse frequency as &str.");
     };
 
+    // Get headers from qsv slice on input file
+    print_status(
+        &args,
+        format!("Getting headers from {input_filename} using qsv slice...").as_str(),
+    );
+    let Ok(headers) = Command::new(qsv_path)
+        .arg("slice")
+        .arg(input_path)
+        .args(["--len", "1"])
+        .arg("--no-headers")
+        .output()
+    else {
+        return fail!("Error: Error while getting headers.");
+    };
+
+    // Parse the headers as &str
+    let Ok(headers_str) = std::str::from_utf8(&headers.stdout) else {
+        return fail!("Error: Unable to parse headers as &str.");
+    };
+
     // Run inference options
     run_inference_options(
         &args,
@@ -682,6 +786,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         &api_key,
         Some(stats_str),
         Some(frequency_str),
+        Some(headers_str),
     )?;
 
     Ok(())
