@@ -1,6 +1,6 @@
 static USAGE: &str = r#"
 Exports a specified Excel/ODS sheet to a CSV file.
-The first row of a sheet is assumed to be the header row.
+The first non-empty row of a sheet is assumed to be the header row.
 
 Examples:
 
@@ -31,12 +31,24 @@ Export the last sheet (negative index)):
 Export the second to last sheet:
     qsv excel -s -2 input.xls
 
+Export a table in an XLSX file:
+    qsv excel --table "Table1" input.xlsx
+
 Export a range of cells in the first sheet:
     qsv excel --range C3:T25 input.xlsx
 
+Export a named range in the workbook:
+    qsv excel --range MyRange input.xlsx
+
 Export a range of cells in the second sheet:
     qsv excel --range C3:T25 -s 1 input.xlsx
 
+Export a range of cells in a sheet by name.
+Note the range name must be enclosed in single quotes in certain shells
+as it may contain special characters like ! and $:
+    qsv excel --range 'Sheet2!C3:T25' input.xlsx
+    qsv excel --range 'Sheet2!$C$3:$T$25' input.xlsx
+
 Export metadata for all sheets in CSV format:
     qsv excel --metadata c input.xlsx
 
@@ -64,17 +76,23 @@ Excel options:
                                Negative indices start from the end (-1 = last sheet). 
                                If the sheet cannot be found, qsv will read the first sheet.
                                [default: 0]
+    --header-row <row>         The header row. Set if other than the first non-empty row of the sheet.
     --metadata <c|s|j|J|S>     Outputs workbook metadata in CSV or JSON format:
-                                 index, sheet_name, headers, type, visible, num_columns, num_rows,
+                                 index, sheet_name, headers, type, visible, column_count, row_count,
                                  safe_headers, safe_headers_count, unsafe_headers, unsafe_headers_count
-                                 and duplicate_headers_count.
+                                 and duplicate_headers_count, names, name_count, tables, table_count.
                                headers is a list of the first row which is presumed to be the header row.
                                type is the sheet type (WorkSheet, DialogSheet, MacroSheet, ChartSheet, Vba).
                                visible is the sheet visibility (Visible, Hidden, VeryHidden).
-                               num_rows includes all rows, including the first row.
+                               row_count includes all rows, including the first row.
                                safe_headers is a list of header with "safe"(database-ready) names.
                                unsafe_headers is a list of headers with "unsafe" names.
                                duplicate_headers_count is a count of duplicate header names.
+                               names is a list of defined names in the workbook, with the associated formula.
+                               name_count is the number of defined names in the workbook.
+                               tables is a list of tables in the workbook, with sheet where the table
+                               is found, columns and the column_count.  (XLSX only)
+                               table_count is the number of tables in the workbook.  (XLSX only)
 
                                In CSV(c) mode, the output is in CSV format.
                                In short(s) CSV mode, the output is in CSV format with only the
@@ -91,6 +109,12 @@ Excel options:
                                
                                All other Excel options are ignored.
                                [default: none]
+
+    --table <table>            An Excel table (case-insensitive) to extract to a CSV.
+                               Only valid for XLSX files. The --sheet option is ignored as a table could
+                               be in any sheet. Overrides --range option.
+    --range <range>            An Excel format range - like RangeName, C:T, C3:T25 or 'Sheet1!C3:T25' to
+                               extract to the CSV. If the range is not found, qsv will exit with an error.
     --error-format <format>    The format to use when formatting error cells.
                                There are 3 formats:
                                  - "code": return the error code.
@@ -110,7 +134,6 @@ Excel options:
                                return the date as if no date-format was specified.
      --keep-zero-time          Keep the time part of a date-time field if it is 00:00:00.
                                By default, qsv will remove the time part if it is 00:00:00.
-     --range <range>           An Excel format range, like C:T or C3:T25, to extract to the CSV.
      -j, --jobs <arg>          The number of jobs to run in parallel.
                                When not set, the number of jobs is set to the number of CPUs detected.
 
@@ -124,11 +147,13 @@ Common options:
 
 use std::{cmp, fmt::Write, io::Read, path::PathBuf};
 
-use calamine::{open_workbook, Data, Error, Range, Reader, SheetType, Sheets};
+use calamine::{
+    open_workbook, open_workbook_auto, Data, Error, HeaderRow, Range, Reader, SheetType, Sheets,
+};
 use file_format::FileFormat;
 use indicatif::HumanCount;
 use log::info;
-use rayon::prelude::{ParallelIterator, ParallelSlice};
+use rayon::prelude::{IndexedParallelIterator, ParallelIterator, ParallelSlice};
 use serde::{Deserialize, Serialize};
 
 use crate::{
@@ -140,8 +165,11 @@ use crate::{
 struct Args {
     arg_input:           String,
     flag_sheet:          String,
+    flag_header_row:     Option<u32>,
     flag_metadata:       String,
     flag_error_format:   String,
+    flag_table:          Option<String>,
+    flag_range:          Option<String>,
     flag_flexible:       bool,
     flag_trim:           bool,
     flag_output:         Option<String>,
@@ -149,7 +177,6 @@ struct Args {
     flag_quiet:          bool,
     flag_date_format:    Option<String>,
     flag_keep_zero_time: bool,
-    flag_range:          String,
     flag_jobs:           Option<usize>,
 }
 
@@ -170,6 +197,14 @@ enum ErrorFormat {
     Both,
 }
 
+#[derive(PartialEq)]
+enum ExportMode {
+    Table,
+    Range,
+    Sheet,
+    NothingToExport,
+}
+
 #[derive(Serialize, Deserialize)]
 struct SheetMetadata {
     index:                   usize,
@@ -177,8 +212,8 @@ struct SheetMetadata {
     typ:                     String,
     visible:                 String,
     headers:                 Vec<String>,
-    num_columns:             usize,
-    num_rows:                usize,
+    column_count:            usize,
+    row_count:               usize,
     safe_headers:            Vec<String>,
     safe_headers_count:      usize,
     unsafe_headers:          Vec<String>,
@@ -200,13 +235,32 @@ impl From<calamine::Error> for CliError {
     }
 }
 
+#[derive(Serialize, Deserialize)]
+
+struct NamesMetadata {
+    name:    String,
+    formula: String,
+}
+
+#[derive(Serialize, Deserialize)]
+struct TableMetadata {
+    name:         String,
+    sheet:        String,
+    columns:      Vec<String>,
+    column_count: usize,
+}
+
 #[derive(Serialize, Deserialize)]
 struct MetadataStruct {
     filename:           String,
     canonical_filename: String,
     format:             String,
-    num_sheets:         usize,
+    sheet_count:        usize,
     sheet:              Vec<SheetMetadata>,
+    names:              Vec<NamesMetadata>,
+    name_count:         usize,
+    tables:             Vec<TableMetadata>,
+    table_count:        usize,
 }
 
 #[derive(Serialize, Deserialize)]
@@ -214,10 +268,11 @@ struct ShortMetadataStruct {
     filename:           String,
     canonical_filename: String,
     format:             String,
-    num_sheets:         usize,
+    sheet_count:        usize,
     sheet:              Vec<ShortSheetMetadata>,
 }
 
+#[derive(Debug)]
 struct RequestedRange {
     // matches args for https://docs.rs/calamine/latest/calamine/struct.Range.html#method.rows
     start: (u32, u32), // upper left, 0 based, row, column
@@ -225,10 +280,11 @@ struct RequestedRange {
 }
 
 impl RequestedRange {
+    /// takes a string like C3 or $C$3 and returns a 0 indexed column number, 2
+    /// returns 0 on missing.
     fn parse_col(col: &str) -> Option<u32> {
-        // takes a string like C3 and returns a 0 indexed column number, 2
-        // returns 0 on missing.
-
+        let mut col: String = col.replace('$', "");
+        col.make_ascii_lowercase();
         col.chars()
             .filter(|c| !c.is_ascii_digit())
             .map(|i| u32::from(i) - (u32::from('a') - 1))
@@ -236,9 +292,11 @@ impl RequestedRange {
             .map(|r| r - 1)
     }
 
+    /// takes a string like R32 or $R$32 and returns 0 indexed row number, 31.
+    /// returns 0 on missing
     fn parse_row(row: &str) -> Option<u32> {
-        // takes a string like R32 and returns 0 indexed row number, 31.
-        // returns 0 on missing
+        let mut row = row.replace('$', "");
+        row.make_ascii_lowercase();
         row.chars()
             .filter(char::is_ascii_digit)
             .collect::<String>()
@@ -247,9 +305,8 @@ impl RequestedRange {
             .map(|r| r - 1)
     }
 
-    pub fn from_string(range: &str, worksheet_size: (usize, usize)) -> CliResult<RequestedRange> {
-        // worksheet_size is from range.getsize, height,width.  1 indexed.
-
+    /// worksheet_size is from range.getsize, height,width.  1 indexed.
+    fn from_string(range: &str, worksheet_size: (usize, usize)) -> CliResult<RequestedRange> {
         let Some((start, end)) = range.split_once(':') else {
             return fail_clierror!("Unable to parse range string");
         };
@@ -269,6 +326,68 @@ impl RequestedRange {
     }
 }
 
+/// Parses and validates the requested range for a specific sheet in an Excel workbook.
+///
+/// # Arguments
+///
+/// * `requested_range` - A string in the format "SheetName!Range" (e.g., "Sheet1!A1:B10").
+/// * `sheet` - A mutable reference to a String that will be updated with the sheet name.
+/// * `sheet_names` - A slice of available sheet names in the workbook.
+/// * `sheet_range` - A mutable reference to a Range<Data> that will be updated with the worksheet
+///   range.
+/// * `sheets` - A mutable reference to the Sheets struct containing the workbook data.
+///
+/// # Returns
+///
+/// * `Ok(String)` - The range part of the requested_range if successful.
+/// * `Err(CliError)` - If there's an error in parsing or finding the requested sheet/range.
+///
+/// # Errors
+///
+/// This function will return an error if:
+/// * The requested_range format is invalid (doesn't contain a '!' separator).
+/// * The specified sheet name is not found in the workbook.
+/// * The worksheet range cannot be retrieved for the specified sheet.
+fn get_requested_range(
+    requested_range: &str,
+    sheet: &mut String,
+    sheet_names: &[String],
+    sheet_range: &mut Range<Data>,
+    sheets: &mut Sheets<std::io::BufReader<std::fs::File>>,
+) -> Result<String, CliError> {
+    let split_range: Vec<&str> = requested_range.split('!').collect();
+
+    // Ensure that both sheet name and range are provided
+    if split_range.len() != 2 {
+        return fail_clierror!("Invalid range format. Expected format: 'SheetName!Range'.");
+    }
+
+    let sheet_name = split_range[0].to_lowercase();
+    sheet.clone_from(&sheet_name);
+    let range_str = split_range[1].to_string();
+
+    // Find the sheet index
+    let sheet_index = sheet_names
+        .iter()
+        .position(|s| s.to_lowercase() == sheet_name)
+        .unwrap_or(usize::MAX);
+
+    if sheet_index == usize::MAX {
+        return fail_clierror!("Sheet \"{sheet}\" not found in available sheets: {sheet_names:?}.");
+    }
+
+    // Get the worksheet range
+    *sheet_range = if let Some(result) = sheets.worksheet_range_at(sheet_index) {
+        result?
+    } else {
+        return fail_clierror!(
+            "Cannot get sheet: \"{sheet}\". Available sheets are: {sheet_names:?}"
+        );
+    };
+
+    Ok(range_str)
+}
+
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
 
@@ -308,10 +427,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .unwrap_or_default()
         .to_ascii_lowercase();
 
-    let requested_range = args.flag_range.to_lowercase();
-
     let mut ods_flag = false;
-    let mut workbook = match (format).as_str() {
+    let mut sheets = match (format).as_str() {
         "xls" | "xla" => Sheets::Xls(open_workbook(path).map_err(Error::Xls)?),
         "xlsx" | "xlsm" => Sheets::Xlsx(open_workbook(path).map_err(Error::Xlsx)?),
         "xlsb" => Sheets::Xlsb(open_workbook(path).map_err(Error::Xlsb)?),
@@ -327,13 +444,13 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         },
     };
 
-    let sheet_names = workbook.sheet_names();
+    let sheet_names = sheets.sheet_names();
     if sheet_names.is_empty() {
         return fail!("No sheets found.");
     }
-    let num_sheets = sheet_names.len();
+    let sheet_count = sheet_names.len();
 
-    let mut wtr = Config::new(&args.flag_output)
+    let mut wtr = Config::new(args.flag_output.as_ref())
         .flexible(args.flag_flexible)
         .delimiter(args.flag_delimiter)
         .writer()?;
@@ -354,6 +471,33 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     // check if we're exporting workbook metadata only
     if metadata_mode != MetadataMode::None {
+        let mut names_vec = vec![];
+        let mut table_metadata_vec = vec![];
+
+        sheets.defined_names().iter().for_each(|name| {
+            names_vec.push(NamesMetadata {
+                name:    name.0.clone(),
+                formula: name.1.clone(),
+            });
+        });
+
+        if format == "xlsx" {
+            let mut xlsx_wb: calamine::Xlsx<_> = open_workbook(path).map_err(Error::Xlsx)?;
+            xlsx_wb.load_tables().map_err(Error::Xlsx)?;
+            let mut columns;
+            let tables_vec: Vec<String> = xlsx_wb.table_names().into_iter().cloned().collect();
+            for table in &tables_vec {
+                let table_metadata = xlsx_wb.table_by_name(table).map_err(Error::Xlsx)?;
+                columns = table_metadata.columns().to_vec();
+                table_metadata_vec.push(TableMetadata {
+                    name: table_metadata.name().to_owned(),
+                    sheet: table_metadata.sheet_name().to_owned(),
+                    column_count: columns.len(),
+                    columns,
+                });
+            }
+        }
+
         let mut excelmetadata_struct = MetadataStruct {
             filename: filename.clone(),
             canonical_filename: canonical_filename.clone(),
@@ -362,8 +506,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             } else {
                 format!("Excel: {format}")
             },
-            num_sheets,
+            sheet_count,
             sheet: vec![],
+            name_count: names_vec.len(),
+            names: names_vec,
+            table_count: table_metadata_vec.len(),
+            tables: table_metadata_vec,
         };
         let mut metadata_record;
         let sheet_vec = sheet_names;
@@ -373,11 +521,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 || metadata_mode == MetadataMode::ShortJSON
             {
                 Range::empty()
-            } else if let Some(result) = workbook.worksheet_range_at(i) {
+            } else if let Some(result) = sheets.worksheet_range_at(i) {
                 match result {
                     Ok(result) => result,
                     Err(e) => {
-                        if workbook.sheets_metadata()[i].typ == SheetType::ChartSheet {
+                        if sheets.sheets_metadata()[i].typ == SheetType::ChartSheet {
                             // return an empty range for ChartSheet
                             Range::empty()
                         } else {
@@ -389,17 +537,17 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 Range::empty()
             };
 
-            let (header_vec, num_columns, num_rows, safenames_vec, unsafeheaders_vec, dupe_count) =
+            let (header_vec, column_count, row_count, safenames_vec, unsafeheaders_vec, dupe_count) =
                 if range.is_empty() {
                     (vec![], 0_usize, 0_usize, vec![], vec![], 0_usize)
                 } else {
-                    let (num_rows, num_columns) = range.get_size();
+                    let (row_count, column_count) = range.get_size();
                     let mut sheet_rows = range.rows();
-                    let mut checkednames_vec: Vec<String> = Vec::with_capacity(num_columns);
-                    let mut safenames_vec: Vec<String> = Vec::with_capacity(num_columns);
+                    let mut checkednames_vec: Vec<String> = Vec::with_capacity(column_count);
+                    let mut safenames_vec: Vec<String> = Vec::with_capacity(column_count);
                     let mut unsafenames_vec: Vec<String> = Vec::new();
                     let mut dupe_count = 0_usize;
-                    let mut header_vec: Vec<String> = Vec::with_capacity(num_columns);
+                    let mut header_vec: Vec<String> = Vec::with_capacity(column_count);
 
                     if let Some(first_row) = sheet_rows.next() {
                         header_vec = first_row
@@ -429,8 +577,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
                     (
                         header_vec,
-                        num_columns,
-                        num_rows,
+                        column_count,
+                        row_count,
                         safenames_vec,
                         unsafenames_vec,
                         dupe_count,
@@ -439,11 +587,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             let sheetmetadata_struct = SheetMetadata {
                 index: i,
                 name: sheet_name.to_string(),
-                typ: format!("{:?}", workbook.sheets_metadata()[i].typ),
-                visible: format!("{:?}", workbook.sheets_metadata()[i].visible),
+                typ: format!("{:?}", sheets.sheets_metadata()[i].typ),
+                visible: format!("{:?}", sheets.sheets_metadata()[i].visible),
                 headers: header_vec,
-                num_columns,
-                num_rows,
+                column_count,
+                row_count,
                 safe_headers_count: safenames_vec.len(),
                 safe_headers: safenames_vec,
                 unsafe_headers_count: unsafeheaders_vec.len(),
@@ -462,8 +610,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     "type",
                     "visible",
                     "headers",
-                    "num_columns",
-                    "num_rows",
+                    "column_count",
+                    "row_count",
                     "safe_headers",
                     "safe_headers_count",
                     "unsafe_headers",
@@ -481,8 +629,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         format!("{:?}", sheetmetadata.headers),
                         sheetmetadata.typ,
                         sheetmetadata.visible,
-                        sheetmetadata.num_columns.to_string(),
-                        sheetmetadata.num_rows.to_string(),
+                        sheetmetadata.column_count.to_string(),
+                        sheetmetadata.row_count.to_string(),
                         format!("{:?}", sheetmetadata.safe_headers),
                         sheetmetadata.safe_headers_count.to_string(),
                         format!("{:?}", sheetmetadata.unsafe_headers),
@@ -532,7 +680,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     filename,
                     canonical_filename,
                     format,
-                    num_sheets,
+                    sheet_count,
                     sheet: vec![],
                 };
                 for sheetmetadata in excelmetadata_struct.sheet {
@@ -560,11 +708,39 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // --------------------------------------------------------------------
     // we're not exporting metadata, we're exporting the spreadsheet to CSV
 
+    // check if a table is being requested
+    let table = if let Some(ref requested_table) = args.flag_table {
+        if format == "xlsx" {
+            let mut xlsx_wb: calamine::Xlsx<_> = open_workbook(path).map_err(Error::Xlsx)?;
+            xlsx_wb.load_tables().map_err(Error::Xlsx)?;
+            let table_names = xlsx_wb.table_names();
+            let mut found_table = String::new();
+            for table_name in &table_names {
+                if table_name.to_lowercase() == requested_table.to_lowercase() {
+                    found_table = (*table_name).to_string();
+                    break;
+                }
+            }
+            if found_table.is_empty() {
+                return fail_clierror!(
+                    "\"{requested_table}\" table not found. Available tables are {table_names:?}"
+                );
+            };
+            Some(xlsx_wb.table_by_name(&found_table).map_err(Error::Xlsx)?)
+        } else {
+            return fail_incorrectusage_clierror!("--table is only valid for XLSX files");
+        }
+    } else {
+        None
+    };
+
     // convert sheet_names to lowercase so we can do a case-insensitive compare
     let lower_sheet_names: Vec<String> = sheet_names.iter().map(|s| s.to_lowercase()).collect();
 
     // if --sheet name was passed, see if its a valid sheet name.
-    let mut sheet = if lower_sheet_names.contains(&args.flag_sheet.to_lowercase()) {
+    let mut sheet = if table.is_some() {
+        String::new()
+    } else if lower_sheet_names.contains(&args.flag_sheet.to_lowercase()) {
         args.flag_sheet
     } else {
         // otherwise, if --sheet is a number, its a zero-based index, fetch it
@@ -584,8 +760,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 sheet_names[cmp::max(
                     0,
                     cmp::min(
-                        num_sheets - 1,
-                        num_sheets.abs_diff(sheet_index.unsigned_abs() as usize),
+                        sheet_count - 1,
+                        sheet_count.abs_diff(sheet_index.unsigned_abs() as usize),
                     ),
                 )]
                 .to_string()
@@ -604,45 +780,118 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     }
     .to_lowercase();
 
-    let sheet_index = if let Some(idx) = lower_sheet_names.iter().position(|s| *s == sheet) {
+    let sheet_index = if table.is_some() {
+        0
+    } else if let Some(idx) = lower_sheet_names.iter().position(|s| *s == sheet) {
         // set to actual name of the sheet, not the one passed using the --sheet option,
         // as we process the option case insensitively
         // safety: it's safe to use index access here because lower_sheet_names is a lowercase copy
         // of sheet_names
         sheet.clone_from(&sheet_names[idx]);
+        let sheet_type = sheets.sheets_metadata()[idx].typ;
+        if sheet_type != SheetType::WorkSheet {
+            return fail_incorrectusage_clierror!(
+                "Can only export Worksheets. \"{sheet}\" is a {sheet_type:?}."
+            );
+        }
         idx
     } else {
         return fail_clierror!("Cannot get sheet index for {sheet}");
     };
 
-    let sheet_type = workbook.sheets_metadata()[sheet_index].typ;
-    if sheet_type != SheetType::WorkSheet {
-        return fail_incorrectusage_clierror!(
-            "Can only export Worksheets. {sheet} is a {sheet_type:?}."
-        );
-    }
-
-    let mut range = if let Some(result) = workbook.worksheet_range_at(sheet_index) {
-        result?
+    let header_row: HeaderRow = if let Some(hr) = args.flag_header_row {
+        info!("processing row {hr} as header...");
+        HeaderRow::Row(hr)
     } else {
-        Range::empty()
+        info!("processing first non-empty row as header...");
+        HeaderRow::FirstNonEmptyRow
     };
+    sheets.with_header_row(header_row);
 
-    if !requested_range.is_empty() {
-        info!("using range: {requested_range}");
-        let parsed_range = RequestedRange::from_string(&requested_range, range.get_size())?;
-        info!(
-            "Range start: {} {}",
-            parsed_range.start.0, parsed_range.start.1
-        );
-        info!("Range end: {} {}", parsed_range.end.0, parsed_range.end.1);
-        if parsed_range.start < range.start().unwrap_or((0, 0))
-            || parsed_range.end > range.end().unwrap_or((0, 0))
-        {
-            return fail_clierror!("Cannot retrieve range {requested_range}: larger than sheet");
+    let export_mode: ExportMode;
+    let table_headers;
+    let range: Range<Data> = if let Some(table) = table {
+        export_mode = ExportMode::Table;
+        table_headers = table.columns().to_vec();
+        table.data().to_owned()
+    } else {
+        table_headers = vec![];
+        if let Some(ref requested_range) = args.flag_range {
+            export_mode = ExportMode::Range;
+            info!("using range: {requested_range}");
+            let mut sheet_range = Range::empty();
+            let name_contains_exclamation: bool = requested_range.contains('!');
+            let parsed_range = if requested_range.contains(':') && !name_contains_exclamation {
+                // if there is a colon, we treat it as a range for the current sheet
+                sheet_range = if let Some(result) = sheets.worksheet_range_at(sheet_index) {
+                    result?
+                } else {
+                    Range::empty()
+                };
+                RequestedRange::from_string(requested_range, sheet_range.get_size())?
+            } else if name_contains_exclamation {
+                // if there is an exclamation mark, we treat it as a range in an explicitly named
+                // sheet parse the range string to get the sheet name and the range
+                // e.g. Sheet2!$C$20:$E$24
+                // is sheet name "Sheet2" and the range $C$20:$E$24
+                let range_str = get_requested_range(
+                    requested_range,
+                    &mut sheet,
+                    &sheet_names,
+                    &mut sheet_range,
+                    &mut sheets,
+                )?;
+                RequestedRange::from_string(&range_str, sheet_range.get_size())?
+            } else {
+                // if there is no colon, we treat it as a named range
+                let wb = open_workbook_auto(path)?;
+                let named_ranges = wb.defined_names();
+                let mut found_range = String::new();
+                for named_range in named_ranges {
+                    if named_range.0.to_lowercase() == requested_range.to_lowercase() {
+                        found_range = named_range.1.to_string();
+                        break;
+                    }
+                }
+                if found_range.is_empty() {
+                    return fail_clierror!(
+                        "\"{requested_range}\" named range not found. Available named ranges are \
+                         {named_ranges:?}"
+                    );
+                };
+                let range_str = get_requested_range(
+                    &found_range,
+                    &mut sheet,
+                    &sheet_names,
+                    &mut sheet_range,
+                    &mut sheets,
+                )?;
+                RequestedRange::from_string(&range_str, sheet_range.get_size())?
+            };
+            info!("parsed_range: {parsed_range:?}");
+            let range_result = if parsed_range.start < sheet_range.start().unwrap_or((0, 0))
+                || parsed_range.end > sheet_range.end().unwrap_or((0, 0))
+            {
+                return fail_clierror!(
+                    "Cannot retrieve range \"{requested_range}\": larger than sheet"
+                );
+            } else {
+                sheet_range.range(parsed_range.start, parsed_range.end)
+            };
+            if range_result.is_empty() {
+                return fail_clierror!(
+                    "\"{requested_range}\" range in sheet \"{sheet}\" is empty."
+                );
+            }
+            range_result
+        } else if let Some(result) = sheets.worksheet_range_at(sheet_index) {
+            export_mode = ExportMode::Sheet;
+            result?
+        } else {
+            export_mode = ExportMode::NothingToExport;
+            Range::empty()
         }
-        range = range.range(parsed_range.start, parsed_range.end);
-    }
+    };
 
     let (row_count, col_count) = range.get_size();
 
@@ -653,10 +902,13 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     };
 
     if row_count == 0 {
-        if !requested_range.is_empty() {
-            return fail_clierror!("\"{requested_range}\" range in sheet \"{sheet}\" is empty.");
-        }
-        return fail_clierror!("\"{sheet}\" sheet is empty.");
+        let msg = match export_mode {
+            ExportMode::Table => format!("Table: {:?} ", args.flag_table),
+            ExportMode::Sheet => format!("Sheet: {sheet} "),
+            ExportMode::Range => format!("Range: {:?} ", args.flag_range),
+            ExportMode::NothingToExport => String::new(),
+        };
+        return fail_clierror!("\"{msg}\"is empty.");
     }
     // there are rows to export
     let mut rows_iter = range.rows();
@@ -668,7 +920,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let sheet_formulas = if error_format == ErrorFormat::Code {
         Range::empty()
     } else {
-        workbook.worksheet_formula(&sheet)?
+        sheets.worksheet_formula(&sheet)?
     };
 
     // amortize allocations
@@ -676,8 +928,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut trimmed_record = csv::StringRecord::with_capacity(500, col_count);
 
     // get headers
-    info!("exporting sheet ({sheet})... processing first row as header...");
-    let headers = range.headers().unwrap_or_default();
+    info!("exporting sheet ({sheet})...");
+    let headers = if export_mode == ExportMode::Table {
+        table_headers
+    } else {
+        range.headers().unwrap_or_default()
+    };
     for header in headers {
         record.push_field(&header);
     }
@@ -727,12 +983,17 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let keep_zero_time = args.flag_keep_zero_time;
     let formula_get_value_error = "cannot get formula".to_string();
 
-    let processed_rows: Vec<Vec<csv::StringRecord>> = rows
-        .par_chunks(chunk_size)
+    let mut processed_rows: Vec<Vec<csv::StringRecord>> = Vec::with_capacity(row_count);
+
+    rows.par_chunks(chunk_size)
         .map(|chunk| {
             // amortize allocations
             let mut record = csv::StringRecord::with_capacity(500, col_count);
-            let mut trimmed_record = csv::StringRecord::with_capacity(500, col_count);
+            let mut trimmed_record = if trim {
+                csv::StringRecord::with_capacity(500, col_count)
+            } else {
+                csv::StringRecord::new()
+            };
             let mut float_val;
             let mut work_date;
             let mut ryu_buffer = ryu::Buffer::new();
@@ -850,8 +1111,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                             trimmed_record.push_field(field);
                         }
                     });
-                    record.clone_from(&trimmed_record);
-                    trimmed_record.clear();
+                    record = std::mem::take(&mut trimmed_record);
                 }
 
                 // we use mem::take here to avoid a clone/allocation of the record
@@ -861,7 +1121,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             }
             processed_chunk
         })
-        .collect();
+        .collect_into_vec(&mut processed_rows);
 
     // rayon collect() guarantees original order,
     // so we can just write results for each chunk in order
@@ -874,10 +1134,18 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     wtr.flush()?;
 
     if !args.flag_quiet {
+        let msg = match export_mode {
+            ExportMode::Table => format!("Table: \"{}\"", args.flag_table.unwrap()),
+            ExportMode::Range => {
+                format!("Sheet: \"{sheet}\" Range:\"{}\"", args.flag_range.unwrap())
+            },
+            ExportMode::Sheet => format!("\"{sheet}\" sheet"),
+            ExportMode::NothingToExport => String::new(),
+        };
         winfo!(
             "{}",
             format!(
-                "{} {}-column rows exported from \"{sheet}\" sheet",
+                "{} {}-column rows exported from {msg}",
                 HumanCount(row_count.saturating_sub(1) as u64),
                 HumanCount(col_count as u64),
             )
