@@ -525,14 +525,14 @@ async fn get_file_to_sniff(args: &Args, tmpdir: &tempfile::TempDir) -> CliResult
                     // incomplete lines. We do this coz we streamed the download and the downloaded
                     // file may be more than the sample size, and the final line may be incomplete.
                     wtr_file_path = path.display().to_string();
-                    let mut wtr = Config::new(&Some(wtr_file_path.clone()))
+                    let mut wtr = Config::new(Some(wtr_file_path.clone()).as_ref())
                         .no_headers(false)
                         .flexible(true)
                         .quote_style(csv::QuoteStyle::NonNumeric)
                         .writer()?;
 
                     let retrieved_name = file.path().to_str().unwrap().to_string();
-                    let config = Config::new(&Some(retrieved_name))
+                    let config = Config::new(Some(retrieved_name).as_ref())
                         .delimiter(args.flag_delimiter)
                         // we say no_headers so we can just copy the downloaded file over
                         // including headers, to the exact sample size file
@@ -807,7 +807,7 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
         );
     }
 
-    let conf = Config::new(&Some(sfile_info.file_to_sniff.clone()))
+    let conf = Config::new(Some(sfile_info.file_to_sniff.clone()).as_ref())
         .flexible(true)
         .delimiter(args.flag_delimiter);
     let n_rows = if sfile_info.downloaded_records == 0 {
