@@ -75,6 +75,8 @@ fn index_outdated_stats() {
             "sort_order",
             "min_length",
             "max_length",
+            "sum_length",
+            "avg_length",
             "mean",
             "sem",
             "stddev",
@@ -95,6 +97,8 @@ fn index_outdated_stats() {
             "Ascending",
             "1",
             "1",
+            "3",
+            "1",
             "",
             "",
             "",
@@ -115,6 +119,8 @@ fn index_outdated_stats() {
             "Descending",
             "1",
             "1",
+            "3",
+            "1",
             "2",
             "0.4714",
             "0.8165",
